@@ -30,7 +30,7 @@ typedef enum {
   VIK_CLIPBOARD_DATA_SUBLAYER
 } VikClipboardDataType;
 
-void a_clipboard_copy(VikClipboardDataType  type, guint16 layer_type, gint subtype, guint len, guint8 * data);
+void a_clipboard_copy(VikClipboardDataType  type, guint16 layer_type, gint subtype, guint len, const gchar* text, guint8 * data);
 void a_clipboard_copy_selected ( VikLayersPanel *vlp );
 gboolean a_clipboard_paste ( VikLayersPanel *vlp );
 
