@@ -24,8 +24,15 @@
 #include "acquire.h"
 
 extern VikDataSourceInterface vik_datasource_gps_interface;
+extern VikDataSourceInterface vik_datasource_file_interface;
 extern VikDataSourceInterface vik_datasource_google_interface;
+#ifdef VIK_CONFIG_OPENSTREETMAP
+extern VikDataSourceInterface vik_datasource_osm_interface;
+#endif
 #ifdef VIK_CONFIG_GEOCACHES
 extern VikDataSourceInterface vik_datasource_gc_interface;
 #endif
+#ifdef VIK_CONFIG_GEOTAG
+extern VikDataSourceInterface vik_datasource_geotag_interface;
+#endif
 #endif
