@@ -122,8 +122,33 @@ typedef enum {
 gdouble a_vik_get_default_lat ( );
 gdouble a_vik_get_default_long ( );
 
+/* KML export preferences */
+typedef enum {
+  VIK_KML_EXPORT_UNITS_METRIC,
+  VIK_KML_EXPORT_UNITS_STATUTE,
+  VIK_KML_EXPORT_UNITS_NAUTICAL,
+} vik_kml_export_units_t;
+
+vik_kml_export_units_t a_vik_get_kml_export_units ( );
+
+#ifndef WINDOWS
+/* Windows automatically uses the system defined viewer
+   ATM for other systems need to specify the program to use */
+const gchar* a_vik_get_image_viewer ( );
+#endif
+
+const gchar* a_vik_get_external_gpx_program_1 ( );
+
+const gchar* a_vik_get_external_gpx_program_2 ( );
+
 /* Group for global preferences */
 #define VIKING_PREFERENCES_GROUP_KEY "viking.globals"
 #define VIKING_PREFERENCES_NAMESPACE "viking.globals."
 
+/* Another group of global preferences,
+  but in a separate section to try to keep things organized */
+/* AKA Export/External Prefs */
+#define VIKING_PREFERENCES_IO_GROUP_KEY "viking.io"
+#define VIKING_PREFERENCES_IO_NAMESPACE "viking.io."
+
 #endif
