@@ -14,7 +14,7 @@ extern const GdkPixdata mover_22_pixbuf;
 extern const GdkPixdata ruler_18_pixbuf;
 extern const GdkPixdata showpic_18_pixbuf;
 extern const GdkPixdata zoom_18_pixbuf;
-extern const GdkPixdata iscissors_18_pixbuf;
+extern const GdkPixdata route_finder_18_pixbuf;
 extern const GdkPixdata select_18_pixbuf;
 extern const GdkPixdata thumbnails_pixbuf;
 extern const GdkPixdata vikaggregatelayer_pixbuf;
@@ -228,7 +228,7 @@ extern const GdkPixdata cursor_geozoom_pixbuf;
 extern const GdkPixdata cursor_ruler_pixbuf;
 extern const GdkPixdata cursor_addwp_pixbuf;
 extern const GdkPixdata cursor_edwp_pixbuf;
-extern const GdkPixdata cursor_iscissors_pixbuf;
+extern const GdkPixdata cursor_route_finder_pixbuf;
 extern const GdkPixdata cursor_showpic_pixbuf;
 extern const GdkPixdata cursor_demdl_pixbuf;
 extern const GdkPixdata cursor_geomove_pixbuf;
