@@ -28,6 +28,7 @@
 #include "mapcache.h"
 #include "background.h"
 #include "dems.h"
+#include "babel.h"
 #include "curl_download.h"
 #include "preferences.h"
 #include "globals.h"
@@ -62,7 +63,7 @@ void a_datasource_gc_init();
 static guint window_count = 0;
 
 static VikWindow *new_window ();
-static void open_window ( VikWindow *vw, const gchar **files );
+static void open_window ( VikWindow *vw, GSList *files );
 static void destroy( GtkWidget *widget,
                      gpointer   data );
 
@@ -105,14 +106,25 @@ static VikWindow *new_window ()
   return NULL;
 }
 
-static void open_window ( VikWindow *vw, const gchar **files )
+static void open_window ( VikWindow *vw, GSList *files )
 {
-  VikWindow *newvw = new_window();
-  gboolean change_fn = (!files[1]); /* only change fn if one file */
-  if ( newvw )
-    while ( *files ) {
-      vik_window_open_file ( newvw, *(files++), change_fn );
+  gboolean change_fn = (g_slist_length(files) == 1); /* only change fn if one file */
+  GSList *cur_file = files;
+  while ( cur_file ) {
+    // Only open a new window if a viking file
+    gchar *file_name = cur_file->data;
+    if (vw != NULL && check_file_magic_vik ( file_name ) ) {
+      VikWindow *newvw = new_window();
+      if (newvw)
+	vik_window_open_file ( newvw, file_name, change_fn );
     }
+    else {
+      vik_window_open_file ( vw, file_name, change_fn );
+    }
+    g_free (file_name);
+    cur_file = g_slist_next (cur_file);
+  }
+  g_slist_free (files);
 }
 
 /* Options */
@@ -176,6 +188,8 @@ int main( int argc, char *argv[] )
   a_download_init();
   curl_download_init();
 
+  a_babel_init ();
+
   /* Init modules/plugins */
   modules_init();
 
@@ -205,6 +219,8 @@ int main( int argc, char *argv[] )
   gtk_main ();
   gdk_threads_leave ();
 
+  a_babel_uninit ();
+
   a_background_uninit ();
   a_mapcache_uninit ();
   a_dems_uninit ();
