@@ -32,6 +32,6 @@
 #define VIK_TRW_LAYER_PROPWIN_DEL_DUP 3
 #define VIK_TRW_LAYER_PROPWIN_SPLIT_MARKER 4
 
-void vik_trw_layer_propwin_run ( GtkWindow *parent, VikTrwLayer *vtl, VikTrack *tr, gpointer vlp, gchar *trackname );
+void vik_trw_layer_propwin_run ( GtkWindow *parent, VikTrwLayer *vtl, VikTrack *tr, gpointer vlp, gchar *trackname, VikViewport *vvp );
 
 #endif
