@@ -28,6 +28,7 @@
 #include <gtk/gtk.h>
 
 #include "vikviewport.h"
+#include "vikstatus.h"
 
 G_BEGIN_DECLS
 
@@ -57,6 +58,8 @@ struct _VikLayer;
 void vik_window_selected_layer(VikWindow *vw, struct _VikLayer *vl);
 struct _VikViewport * vik_window_viewport(VikWindow *vw);
 struct _VikLayersPanel * vik_window_layers_panel(VikWindow *vw);
+struct _VikStatusbar * vik_window_get_statusbar(VikWindow *vw);
+
 void vik_window_set_redraw_trigger(struct _VikLayer *vl);
 
 void vik_window_enable_layer_tool ( VikWindow *vw, gint layer_id, gint tool_id );
